@@ -97,10 +97,14 @@ apsrtable <- function (...,
                                   x$se <- sqrt(diag(x$se))
                                 } 
                                 s$coefficients[,3] <- tval <- est / x$se
-                                s$coefficients[,4] <-
+                                e <- try(s$coefficients[,4] <-
                                   2 * pt(abs(tval),
                                          length(x$residuals) - x$rank,
-                                         lower.tail=FALSE)
+                                         lower.tail=FALSE),silent=TRUE)
+                                if(inherits(e,"try-error")){
+                                  s$coefficients[, 4] <-
+                                    2*pnorm(abs(tval),lower.tail=FALSE)
+                                }
                                 s$se <- x$se }
                               if(se == "pval") {
                                 s$coefficients[,2] <- s$coefficients[,4]
@@ -156,7 +160,7 @@ model.summaries <- coefPosition(model.summaries, coefnames)
     }
   
   
-  out.table <- lapply(model.summaries, function(x){
+  out.table <- lapply(model.summaries, function(x){  
     var.pos <- attr(x,"var.pos")
     model.out <- model.se.out <- star.out <- rep(NA,length(coefnames))
     model.out[var.pos] <- x$coefficients[,1]
@@ -524,7 +528,7 @@ apsrtableSummary.lrm <- function (x) {
     ##cat("\n")
   }
   else if (!is.null(x$na.action)) 
-    naprint(x$na.action)
+    ##naprint(x$na.action)
   ns <- x$non.slopes
   nstrata <- x$nstrata
   if (!length(nstrata)) 
@@ -600,7 +604,8 @@ apsrtableSummary.lrm <- function (x) {
   class(res) <- "summary.lrm"
   invisible(res)
 }
-modelInfo.summary.lrm <- function(x) {
+
+"modelInfo.summary.lrm" <- function(x) {
   env <- sys.parent()
   digits<- evalq(digits, envir=env)
   x <- as.numeric(x$modelinfo)
@@ -619,14 +624,71 @@ modelInfo.summary.lrm <- function(x) {
                      "$P$"=formatC(x[5],format="f",digits=digits),
                      "C-index"=formatC(x[6],format="f",digits=digits),
                      "Somers $D_{xy}$"=formatC(x[7],format="f",digits=digits),
-                     "$\\gamma"=formatC(x[8],format="f",digits=digits),
-                     "Kendall's tau-a"=formatC(x[9],format="f",digits=digits),
+                     ##"$\\gamma$"=formatC(x[8],format="f",digits=digits),
+                     ##"Kendall's tau-a"=formatC(x[9],format="f",digits=digits),
                      "Nagelkerke $R^2$"=formatC(x[10],format="f",digits=digits),
                      "Brier" = formatC(x[11],format="f",digits=digits))
   class(model.info) <- "model.info"
   invisible(model.info) 
 }
 
+## "apsrtableSummary.mer" <- function(object) {
+##   call <- object@call
+##   digits <- 2
+##   detail <- TRUE
+##   ##print (call)
+##                                         #object <- summary(object)
+##                                         #summ <- summary(object)
+##   fcoef <- fixef(object)
+##                                         #coefs <- attr(summ, "coefs")
+##                                         #useScale <- attr (VarCorr (object), "sc")
+##   useScale <- object@dims["useSc"]
+##   corF <- vcov(object)@factors$correlation
+##   coefs <- cbind(fcoef, corF@sd)
+##   if (length (fcoef) > 0){
+##     if (!object@dims["useSc"]) {
+##       coefs <- coefs[, 1:2, drop = FALSE]
+##       stat <- coefs[, 1]/coefs[, 2]
+##       pval <- 2 * pnorm(abs(stat), lower = FALSE)
+##       coefs <- cbind(coefs, `z value` = stat, `Pr(>|z|)` = pval)
+##     }
+##     else {
+##       stat <- coefs[, 1]/coefs[, 2]
+##       coefs <- cbind(coefs, `t value` = stat)
+##     }
+##     dimnames(coefs)[[2]][1:2] <- c("coef.est", "coef.se")
+##     if(detail){
+##       pfround (coefs, digits)
+##     }
+##     else{
+##       pfround(coefs[,1:2], digits)
+##     }
+##   }
+##   ##cat("\nError terms:\n")
+##   vc <- as.matrix.VarCorr (VarCorr (object), useScale=useScale, digits)
+##   ##print (vc[,c(1:2,4:ncol(vc))], quote=FALSE)
+##   ngrps <- lapply(object@flist, function(x) length(levels(x)))
+##   REML <- object@dims["REML"]
+##   llik <- logLik(object, REML)
+##   AIC <- AIC(llik)
+##   dev <- object@deviance["ML"]     # Dbar
+##   n <- object@dims["n"]
+##   Dhat <- -2*(llik) # Dhat
+##   pD <- dev - Dhat              # pD
+##   DIC <- dev + pD               # DIC=Dbar+pD=Dhat+2pD
+##   ##cat("---\n")
+##   ##cat(sprintf("number of obs: %d, groups: ", n))
+##   ##cat(paste(paste(names(ngrps), ngrps, sep = ", "), collapse = "; "))
+##   ##cat(sprintf("\nAIC = %g, DIC = ", round(AIC,1)))
+##   ##cat(round(DIC, 1))
+##   ##cat("\ndeviance =", fround (dev, 1), "\n")
+##   if (useScale < 0){
+##     overdisp <- paste("overdispersion parameter =", fround (.Call("mer_sigma", object, FALSE, PACKAGE = "lme4"), 1), "\n")
+##   }
+## }
+## setGeneric("apsrtableSummary", def=function(object){standardGeneric("apsrtableSummary")})
+## setMethod("apsrtableSummary", "mer", apsrtableSummary.mer)
+
 
 ## tobit requested by Antonio Ramos added by mjm 2009-02-25
 ## gee requested by Dustin Tingley started by mjm 2009-04-24
@@ -783,6 +845,14 @@ sanitize <- function(str) {
   return(result)
 }
        
+fround <- function (x, digits) {
+    format (round (x, digits), nsmall=digits)
+}
+  
+pfround <- function (x, digits) {
+    print (fround (x, digits), quote=FALSE)
+}
+ 
 
 
 ## A couple of test calls here for random features
